@@ -13,7 +13,7 @@ class BGColor:
     ENDC = '\033[0m'
     BOLD = '\033[1m'
 
-
+# use docker-repo
 @app.command()
 def zelock(tag):
     current_working_directory = os.getcwd()
@@ -24,7 +24,7 @@ def zelock(tag):
         if not is_services: os.system("yarn build --quite")
         os.system("docker buildx create --name armbuilder")
         os.system("docker buildx use armbuilder")
-        os.system(f"docker buildx build --quiet --platform linux/amd64 -t {project_name}:{tag} . --push\n")
+        os.system(f"docker buildx build --platform linux/amd64 -t jirapan/{project_name}:{tag} . --push\n")
         print('======================================================================')
         print(f'{BGColor.OKGREEN}{datetime.now()} :: {project_name} is published', BGColor.ENDC)
         print('======================================================================')
